@@ -12,7 +12,7 @@ import os
 from typing import List, Optional
 
 import related
-from config_builder.BaseConfigClass import BaseConfigClass
+from config_builder import BaseConfigClass
 
 from mlcvzoo_base.configuration.class_mapping_config import ClassMappingConfig
 from mlcvzoo_base.configuration.reduction_mapping_config import ReductionMappingConfig
@@ -48,12 +48,12 @@ class AnnotationHandlerMOTInputDataConfig(BaseConfigClass):
     # considered image file format
     image_format: str = related.StringField(required=False, default=".jpg")
     # specifies which format of which challenge/year should be used
-    mot_format: str = related.StringField(required=False, default=MOTChallengeFormats.MOT20)
+    mot_format: str = related.StringField(required=False, default=MOTChallengeFormats.MOT20.value)
     # specifies how to interpret confidence scores in annotations
     ground_truth: bool = related.BooleanField(required=False, default=True)
 
     def check_values(self) -> bool:
-        return self.mot_format in MOTChallengeFormats.__members__.values()
+        return self.mot_format in [f.value for f in MOTChallengeFormats]
 
 
 @related.mutable(strict=True)
