@@ -52,7 +52,7 @@ class CVATAnnotationWriter(AnnotationWriter):
         # NOTE: generated file will overwrite existing file
         xml_tree_to_file(xml_file_path=self.output_file_path, xml_tree=xml_tree)
 
-        return None
+        return self.output_file_path
 
     @staticmethod
     def annotations_to_xml_tree(
