@@ -64,21 +64,20 @@ class DarknetAnnotationWriter(AnnotationWriter):
 
         min_test = 1
         min_train = 1
-        for annotation_id, annotation in enumerate(annotations):
+        for _, annotation in enumerate(annotations):
 
             image_name, image_extension = os.path.splitext(os.path.basename(annotation.image_path))
 
-            label_txt = open(
+            with open(
                 os.path.join(label_dir, f"{image_name}{label_file_extension}"),
                 "a",
-            )
-            for bounding_box in annotation.bounding_boxes:
-                w = (bounding_box.box.xmax - bounding_box.box.xmin) / annotation.get_width()
-                h = (bounding_box.box.ymax - bounding_box.box.ymin) / annotation.get_height()
-                x = bounding_box.box.xmin / annotation.get_width() + w / 2
-                y = bounding_box.box.ymin / annotation.get_height() + h / 2
-                label_txt.write("{} {} {} {} {}\n".format(bounding_box.class_id, x, y, w, h))
-            label_txt.close()
+            ) as label_txt:
+                for bounding_box in annotation.bounding_boxes:
+                    w = (bounding_box.box.xmax - bounding_box.box.xmin) / annotation.get_width()
+                    h = (bounding_box.box.ymax - bounding_box.box.ymin) / annotation.get_height()
+                    x = bounding_box.box.xmin / annotation.get_width() + w / 2
+                    y = bounding_box.box.ymin / annotation.get_height() + h / 2
+                    label_txt.write("{} {} {} {} {}\n".format(bounding_box.class_id, x, y, w, h))
 
             img_target = os.path.join(jpeg_dir, f"{image_name}{image_extension}")
             if not os.path.exists(img_target):
