@@ -90,6 +90,9 @@ class MetricsComputation:
                     "has to be provided "
                 )
 
+        # Remove duplicates
+        self.class_identifier_list = list(dict.fromkeys(self.class_identifier_list))
+
         self._all_predicted_annotations_dict: Dict[int, Dict[str, List[BaseAnnotation]]] = {
             i: {} for i in range(self.dataset_length)
         }
@@ -666,6 +669,9 @@ class MetricsComputation:
 
         unmatched_gt_bounding_boxes: List[BoundingBox] = []
 
+        if not str(class_identifier) in self._all_gt_annotations_dict[dataset_index]:
+            return ground_truth_annotation, unmatched_gt_bounding_boxes
+
         # Iterate over all ground-truth annotations that containing bounding-box
         # information for this image (dataset_index) and the given class-id
         for gt_annotation in self._all_gt_annotations_dict[dataset_index][str(class_identifier)]:
@@ -755,42 +761,49 @@ class MetricsComputation:
                 # Iterate over all predicted annotations for this image and class-id
                 iou_unmatched_gt_bounding_boxes = copy.deepcopy(unmatched_gt_bounding_boxes)
 
-                for predicted_annotation in self._all_predicted_annotations_dict[dataset_index][
-                    str(class_identifier)
-                ]:
+                if str(class_identifier) in self._all_predicted_annotations_dict[dataset_index]:
+                    for predicted_annotation in self._all_predicted_annotations_dict[
+                        dataset_index
+                    ][str(class_identifier)]:
 
-                    for bounding_box in predicted_annotation.get_bounding_boxes(
-                        include_segmentations=True
-                    ):
-                        iou_unmatched_gt_bounding_boxes = self.__update_computation_dictionaries(
-                            bounding_box=bounding_box,
-                            iou_thresh=iou_thresh,
-                            unmatched_gt_bounding_boxes=iou_unmatched_gt_bounding_boxes,
-                        )
-
-                        # The bounding_box is a FP
-                        if self.computing_data.false_positives_dict[iou_thresh][
-                            BBoxSizeTypes.BBOX_ALL
-                        ][-1]:
-                            self.__update_false_positive_metric_info(
-                                ground_truth_annotation=ground_truth_annotation,
-                                predicted_annotation=predicted_annotation,
-                                bounding_box=bounding_box,
-                                class_identifier=class_identifier,
+                        for bounding_box in predicted_annotation.get_bounding_boxes(
+                            include_segmentations=True
+                        ):
+                            iou_unmatched_gt_bounding_boxes = (
+                                self.__update_computation_dictionaries(
+                                    bounding_box=bounding_box,
+                                    iou_thresh=iou_thresh,
+                                    unmatched_gt_bounding_boxes=iou_unmatched_gt_bounding_boxes,
+                                )
                             )
 
-                # There are ground truth annotations which haven't been matched,
-                # this states that the box is a false negative
-                if (
-                    len(self._all_gt_annotations_dict[dataset_index][str(class_identifier)]) > 0
-                    and len(iou_unmatched_gt_bounding_boxes) > 0
-                    and ground_truth_annotation is not None
-                ):
-                    self.__update_false_negative_metric_info(
-                        ground_truth_annotation=ground_truth_annotation,
-                        iou_unmatched_gt_bounding_boxes=iou_unmatched_gt_bounding_boxes,
-                        class_identifier=class_identifier,
-                    )
+                            # The bounding_box is a FP
+                            if self.computing_data.false_positives_dict[iou_thresh][
+                                BBoxSizeTypes.BBOX_ALL
+                            ][-1]:
+                                self.__update_false_positive_metric_info(
+                                    ground_truth_annotation=ground_truth_annotation,
+                                    predicted_annotation=predicted_annotation,
+                                    bounding_box=bounding_box,
+                                    class_identifier=class_identifier,
+                                )
+
+                    # There are ground truth annotations which haven't been matched,
+                    # this states that the box is a false negative
+                    if (
+                        str(class_identifier) in self._all_gt_annotations_dict[dataset_index]
+                        and len(
+                            self._all_gt_annotations_dict[dataset_index][str(class_identifier)]
+                        )
+                        > 0
+                        and len(iou_unmatched_gt_bounding_boxes) > 0
+                        and ground_truth_annotation is not None
+                    ):
+                        self.__update_false_negative_metric_info(
+                            ground_truth_annotation=ground_truth_annotation,
+                            iou_unmatched_gt_bounding_boxes=iou_unmatched_gt_bounding_boxes,
+                            class_identifier=class_identifier,
+                        )
 
     def __compute_and_update_metrics_step(
         self,
