@@ -13,9 +13,7 @@ import os
 from datetime import datetime
 from typing import Dict, List, Optional
 
-import cv2
 import mlflow
-import numpy as np
 from tensorboardX import SummaryWriter
 
 from mlcvzoo_base.configuration.structs import FileNamePlaceholders
@@ -27,9 +25,9 @@ from mlcvzoo_base.evaluation.object_detection.data_classes import (
     METRIC_IMAGE_INFO_TYPE,
     ODModelEvaluationMetrics,
 )
-from mlcvzoo_base.evaluation.object_detection.structs import BBoxSizeTypes, MetricTypes
+from mlcvzoo_base.evaluation.object_detection.structs import BBoxSizeTypes
 from mlcvzoo_base.evaluation.object_detection.utils import (
-    __draw_annotation_on_tf_image,
+    __create_tf_image,
     generate_img_id_map,
     generate_metric_table,
 )
@@ -196,6 +194,7 @@ def log_false_positive_info_to_tb(
     """
 
     timestamp = datetime.now().strftime("%Y-%m-%dT_%H-%M")
+
     tb_dir = os.path.join(
         tb_logging_config.tensorboard_dir.replace(FileNamePlaceholders.TIMESTAMP, timestamp),
         model_name,
@@ -205,58 +204,10 @@ def log_false_positive_info_to_tb(
 
     logger.debug("Write evaluation metrics/images to tensorboard-dir: '{}'".format(tb_dir))
 
-    fn_color = (255, 0, 0)  # => red colour for false negative boxes
-    fp_color = (0, 0, 0)  # => black colour for false positive boxes
-    gt_color = (255, 255, 255)  # => white colour for ground truth data
-
     img_directory_id_dict: Dict[str, int] = dict()
 
     for class_name, image_dict in metric_image_info_dict.items():
         for image_path, metric_image_info in image_dict.items():
-
-            img = cv2.imread(image_path)
-            img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-
-            # resize to the configured image size
-            height, width, _ = img.shape
-            scale_factor = tb_logging_config.false_positive_image_size / width
-            img = cv2.resize(
-                img,
-                (int(width * scale_factor), int(height * scale_factor)),
-                interpolation=cv2.INTER_AREA,
-            )
-            img = np.asarray(img).astype(np.uint8)
-
-            if (
-                metric_image_info.false_positive_annotation is not None
-                or metric_image_info.false_negative_annotation is not None
-            ) and metric_image_info.ground_truth_annotation is not None:
-                __draw_annotation_on_tf_image(
-                    img=img,
-                    annotation=metric_image_info.ground_truth_annotation,
-                    metric_type=MetricTypes.GROUND_TRUTH,
-                    color=gt_color,
-                    thickness=5,
-                )
-
-            if metric_image_info.false_positive_annotation is not None:
-                __draw_annotation_on_tf_image(
-                    img=img,
-                    annotation=metric_image_info.false_positive_annotation,
-                    metric_type=MetricTypes.FALSE_POSITIVES,
-                    color=fp_color,
-                    thickness=2,
-                )
-
-            if metric_image_info.false_negative_annotation is not None:
-                __draw_annotation_on_tf_image(
-                    img=img,
-                    annotation=metric_image_info.false_negative_annotation,
-                    metric_type=MetricTypes.FALSE_NEGATIVES,
-                    color=fn_color,
-                    thickness=2,
-                )
-
             image_id, img_directory_id_dict = generate_img_id_map(
                 image_path=image_path, img_directory_id_dict=img_directory_id_dict
             )
@@ -289,6 +240,7 @@ def log_false_positive_info_to_tb(
                 fn_count = 0
 
             if gt_count > 0 or fp_count > 0 or fn_count > 0:
+
                 writer.add_images(
                     tag=f"metric_image_info_{class_name}/"
                     f"{os.path.basename(image_path)}_"
@@ -296,7 +248,11 @@ def log_false_positive_info_to_tb(
                     f"GT_{gt_count}_"
                     f"FP_{fp_count}_"
                     f"FN_{fn_count}",
-                    img_tensor=img,
+                    img_tensor=__create_tf_image(
+                        image_path=image_path,
+                        metric_image_info=metric_image_info,
+                        false_positive_image_size=tb_logging_config.false_positive_image_size,
+                    ),
                     global_step=0,
                     dataformats="HWC",
                 )
@@ -321,12 +277,15 @@ def output_evaluation_results(
     Args:
         model_metrics: An ODModelEvaluationMetrics object storing the information of an
                        evaluation computation
-        iou_thresholds: TODO
+        iou_thresholds: Iou thresholds for which to output_evaluation_results. They will be
+                        used to extract the information out of the model_metrics
         score_threshold: Optionally hand over the score threshold, indicating the score
                          threshold that has been used to filter predicted bounding boxes
         nms_threshold: Optionally hand over the nms threshold, indicating the nms
                        threshold that has been used to filter predicted bounding boxes
-        tensorboard_logging: TODO
+        tensorboard_logging: A TensorboardLoggingConfig object defining the behavior for logging
+                             the visualizations of false-positives and false-negatives to
+                             tensorboard
 
     Returns:
         None
