@@ -56,19 +56,21 @@ class MLFLowRunner:
         self.mlflow_run: Optional[ActiveRun] = None
         self.artifact_location: Optional[str] = None
 
-        # Build configuration by instantiating a config-builder object
-        config_builder = ConfigBuilder(
-            class_type=MLFlowConfig,
-            configuration=configuration,
-            yaml_config_path=yaml_config_path,
-            string_replacement_map=string_replacement_map,
-            mutual_attribute_map=mutual_attribute_map,
-            no_checks=no_checks,
-        )
+        if configuration is not None:
+            self.configuration: MLFlowConfig = configuration
+        else:
+            # Build configuration by instantiating a config-builder object
+            config_builder = ConfigBuilder(
+                class_type=MLFlowConfig,
+                yaml_config_path=yaml_config_path,
+                string_replacement_map=string_replacement_map,
+                mutual_attribute_map=mutual_attribute_map,
+                no_checks=no_checks,
+            )
 
-        self.configuration: MLFlowConfig = typing.cast(
-            MLFlowConfig, copy.deepcopy(config_builder.configuration)
-        )
+            self.configuration = typing.cast(
+                MLFlowConfig, copy.deepcopy(config_builder.configuration)
+            )
 
         # Setup base experiments
         if create_experiments:
